@@ -39,4 +39,9 @@ class ItemFilter(object):
         return self.process_items(items)
 
 
+# Deprecated. This backend used to be a function that performed the same task.
 find_related_models = ItemFilter()
+
+
+class PublishedItemFilter(ItemFilter):
+    manager_attr = 'published'
